@@ -1,30 +1,45 @@
-#' Download DataFrame containing the polygons of Australian federal electorates
+#' Download a data frame containing the polygons of Australian federal electorates
+#' 
+#' Downloads and returns a DataFrame containing the points that outline the polygons 
+#' for each of the Australian electorates in the desired federal election. The data were obtained from the 
+#' Australian Electoral Commission and the Australian Bureau of Statistics.
+
 #' 
 #' @param year Desired year, must be one of 2001, 2004, 2007, 2010, 2011, 2013, 2016, 2019
 #' @param ... Additional arguments passed to `download.file`
 #'
-#' Downloads and returns a DataFrame containing the points that outline the polygons 
-#' for each of the Australian electorates in the desired federal election. 
-#' This object is obtained using the `nat_map_download` function. The data were obtained from the 
-#' Australian Electoral Commission and the Australian Bureau of Statistics.
-#'
-#' @return A DataFrame consisting of points outlining each of the Australian federal electorates
-#' 
-#' @examples
-#' \dontrun{
-#' nat_map16 <- nat_map_download(year = 2016)
-#' nat_data16 <- nat_data_download(year = 2016)
-#' # Plot a map of the electorates
-#' library(sp)
-#' plot(sF_16)
+#' @return A data frame consisting of points with the following variables:
+#' \itemize{
+#'     \item id: Numeric identifier for the polygon
+#'     \item long: longitude coordinate of point in polygon
+#'     \item lat: latitude coordinate of point in polygon
+#'     \item order: order for polygon points
+#'     \item hole: whether polygon has a hole
+#'     \item piece: piece for polygon
+#'     \item group: group for polygon
+#'     \item elect_div: Electoral division name
+#'     \item state: Abbreviation for state name
 #' }
 #' 
-#' @export
+#' @examples
+#' library(eechidna)
+#' library(dplyr)
+#' library(ggmap)
+#'
+#' nat_map16 <- nat_map_download(2016)
+#'
+#' nat_map16 %>%
+#'  filter(elect_div=='MELBOURNE') %>%
+#'  qmplot(long, lat, data=., color='red', size=5,
+#'         xlab=NA,ylab=NA) +
+#'  theme(legend.position = 'none')
+#'@export
 nat_map_download <- function(year, ...){
   
+
   year = as.numeric(year)
   suffix = substr(year, 3, 4)
-  url_git = paste0("https://github.com/ropenscilabs/eechidna/raw/master/extra-data/nat_map", suffix, ".rda")
+  url_git = paste0("https://github.com/jforbes14/eechidna/raw/master/extra-data/nat_map", suffix, ".rda")
   
   if (year == 2001) {
     nat_map01 <- 1
@@ -81,33 +96,46 @@ nat_map_download <- function(year, ...){
   
 }
 
-#' Download DataFrame containing the data associated with Australian federal electorates
+#' Download a data frame containing electorate centroids
+#' 
+#' @description
+#' Downloads and returns a data frame containing the points that make up the centroids
+#' for each of the Australian electorates in the desired federal election. 
 #' 
 #' @param year Desired year, must be one of 2001, 2004, 2007, 2010, 2011, 2013, 2016, 2019
 #' @param ... Additional arguments passed to `download.file`
 #'
-#' Downloads and returns a DataFrame containing the points that outline the polygons 
-#' for each of the Australian electorates in the desired federal election. 
-#' This object is obtained using the `nat_data_download` function. The data were obtained from the 
-#' Australian Electoral Commission and the Australian Bureau of Statistics.
 #'
-#' @return A DataFrame with data associated with each of the Australian federal electorates
+#' @return A data frame with data associated with each of the Australian federal electorates
 #' 
-#' @examples
-#' \dontrun{
-#' nat_map16 <- nat_map_download(year = 2016)
-#' nat_data16 <- nat_data_download(year = 2016)
-#' # Plot a map of the electorates
-#' library(sp)
-#' plot(sF_16)
+#' \itemize{
+#'     \item id: Numeric identifier for the polygon
+#'     \item elect_div: Electorate division name   
+#'     \item state: abbreviation of the state name
+#'     \item numccds: AEC variable that might be filled with meaning or a description down the road
+#'     \item area_sqkm: combined square kilometers of each electorate
+#'     \item long_c: longitude coordinate of electorate (polygon) centroid
+#'     \item lat_c: latitude coordinate of electorate (polygon) centroid
+#'     \item x: latitude coordinate for plotting a cartogram
+#'     \item y: longitude coordinate for plotting a cartogram
+#'     \item radius: variable used in the construction of cartogram points
 #' }
 #' 
+#' @examples
+#' library(eechidna)
+#' library(dplyr)
+#' library(ggmap)
+#'
+#' nat_data19 <- nat_data_download(2019)
+#'
+#' nat_data19 %>%
+#'   qmplot(long_c, lat_c, data=.)
 #' @export
 nat_data_download <- function(year, ...){
   
   year = as.numeric(year)
   suffix = substr(year, 3, 4)
-  url_git = paste0("https://github.com/ropenscilabs/eechidna/raw/master/extra-data/nat_data", suffix, ".rda")
+  url_git = paste0("https://github.com/jforbes14/eechidna/raw/master/extra-data/nat_data", suffix, ".rda")
   
   if (year == 2001) {
     nat_data01 <- 1
@@ -189,7 +217,7 @@ sF_download <- function(year, ...){
   
   year = as.numeric(year)
   suffix = substr(year, 3, 4)
-  url_git = paste0("https://github.com/ropenscilabs/eechidna/raw/master/extra-data/sF_", suffix, ".rda")
+  url_git = paste0("https://github.com/jforbes14/eechidna/raw/master/extra-data/sF_", suffix, ".rda")
   
   if (year == 2001) {
     sF_01 <- 1
@@ -299,7 +327,7 @@ sF_download <- function(year, ...){
 firstpref_pollingbooth_download <- function(...){
   fp_pp <- 1
   tmp <- tempfile()
-  utils::download.file("https://github.com/ropenscilabs/eechidna/raw/master/extra-data/fp_pp.rda", tmp)
+  utils::download.file("https://github.com/jforbes14/eechidna/raw/master/extra-data/fp_pp.rda", tmp)
   load(tmp)
   fp_pp 
 }
@@ -358,7 +386,7 @@ firstpref_pollingbooth_download <- function(...){
 twoparty_pollingbooth_download <- function(...){
   tpp_pp <- 1
   tmp <- tempfile()
-  utils::download.file("https://github.com/ropenscilabs/eechidna/raw/master/extra-data/tpp_pp.rda", tmp)
+  utils::download.file("https://github.com/jforbes14/eechidna/raw/master/extra-data/tpp_pp.rda", tmp)
   load(tmp)
   tpp_pp 
 }
@@ -418,7 +446,7 @@ twoparty_pollingbooth_download <- function(...){
 twocand_pollingbooth_download <- function(...){
   tcp_pp <- 1
   tmp <- tempfile()
-  utils::download.file("https://github.com/ropenscilabs/eechidna/raw/master/extra-data/tcp_pp.rda", tmp)
+  utils::download.file("https://github.com/jforbes14/eechidna/raw/master/extra-data/tcp_pp.rda", tmp)
   load(tmp)
   tcp_pp 
 }
